colour.models.rgb_colourspace Module — Colour 0.3.0 documentation

# colour.models.rgb_colourspace Module

## RGB Colourspace

Defines the `RGB_Colourspace` class for the RGB colourspaces dataset from `colour.models.dataset.aces_rgb`, etc...

See also

RGB Colourspaces IPython Notebook

class `colour.models.rgb_colourspace.` `RGB_Colourspace`(name, primaries, whitepoint, to_XYZ=None, to_RGB=None, transfer_function=None, inverse_transfer_function=None)

  Bases: `object`

  Implements support for the RGB colourspaces dataset from `colour.models.dataset.aces_rgb`, etc....

  Parameters: | name (str or unicode) – RGB Colourspace name. primaries (array_like) – RGB Colourspace primaries. whitepoint (array_like) – RGB Colourspace whitepoint. to_XYZ (array_like) – Transformation matrix from colourspace to CIE XYZ colourspace. to_RGB (array_like) – Transformation matrix from CIE XYZ colourspace to colourspace. transfer_function (object) – RGB Colourspace transfer function from linear to colourspace. inverse_transfer_function (object) – RGB Colourspace inverse transfer function from colourspace to linear.

  `inverse_transfer_function`

    Property for self.__inverse_transfer_function private attribute.

    Returns: | self.__inverse_transfer_function.
    Return type: | object

  `name`

    Property for self.__name private attribute.

    Returns: | self.__name.
    Return type: | str or unicode

  `primaries`

    Property for self.__primaries private attribute.

    Returns: | self.__primaries.
    Return type: | array_like, (3, 2)

  `to_RGB`

    Property for self.__to_RGB private attribute.

    Returns: | self.__to_RGB.
    Return type: | array_like, (3, 3)

  `to_XYZ`

    Property for self.__to_XYZ private attribute.

    Returns: | self.__to_XYZ.
    Return type: | array_like, (3, 3)

  `transfer_function`

    Property for self.__transfer_function private attribute.

    Returns: | self.__transfer_function.
    Return type: | object

  `whitepoint`

    Property for self.__whitepoint private attribute.

    Returns: | self.__whitepoint.
    Return type: | array_like